summaryrefslogtreecommitdiffstats
path: root/puic/form.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'puic/form.cpp')
-rw-r--r--puic/form.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/puic/form.cpp b/puic/form.cpp
index 55ee7a7..f909b26 100644
--- a/puic/form.cpp
+++ b/puic/form.cpp
@@ -43,7 +43,7 @@
#if( TQT_VERSION < 0x030101 )
# include <zlib.h>
-static TQByteArray qUncompress( const uchar* data, int nbytes )
+static TQByteArray tqUncompress( const uchar* data, int nbytes )
{
if ( !data ) {
#if defined(TQT_CHECK_RANGE)
@@ -117,13 +117,13 @@ static TQByteArray unzipXPM( TQString data, ulong& length )
r += l - 'a' + 10;
ba[ i ] = r;
}
// qUncompress() expects the first 4 bytes to be the expected length of the
// uncompressed data
ba[0] = ( length & 0xff000000 ) >> 24;
ba[1] = ( length & 0x00ff0000 ) >> 16;
ba[2] = ( length & 0x0000ff00 ) >> 8;
ba[3] = ( length & 0x000000ff );
- TQByteArray baunzip = qUncompress( ba, baSize );
+ TQByteArray baunzip = tqUncompress( ba, baSize );
delete[] ba;
return baunzip;
}
@@ -117,13 +117,13 @@ static TQByteArray unzipXPM( TQString data, ulong& length )
ba[ i ] = r;
}
- // qUncompress() expects the first 4 bytes to be the expected length of the
+ // tqUncompress() expects the first 4 bytes to be the expected length of the
// uncompressed data
ba[0] = ( length & 0xff000000 ) >> 24;